==> jc-1.4.0.tar.gz: gnu/java/security/provider/GnuDSAPublicKey.h <==
// public class gnu.java.security.provider.GnuDSAPublicKey

// class file dependencies
// @dep_class 66829c74362aba21 gnu_java_security_provider_GnuDSAPublicKey
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDSAPublicKey_H_
#define _JC_gnu_java_security_provider_GnuDSAPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_interfaces_DSAParams$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$refs	_jc_gnu_java_security_provider_GnuDSAPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object	_jc_gnu_java_security_provider_GnuDSAPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods	_jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtable	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDSAPublicKey$method$_init$af886985c1050c26(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getParams$cf8a9747be586d14(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getParams$cf8a9747be586d14;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getY$e067a5f1fb934d2a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
	struct _jc_object	*(*getParams$cf8a9747be586d14)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods	gnu_java_security_provider_GnuDSAPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs {
	_jc_byte_array	*encodedKey;
	struct _jc_java_math_BigInteger$object	*y;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$refs {
    _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs	gnu_java_security_provider_GnuDSAPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs	gnu_java_security_provider_GnuDSAPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object {
	_jc_gnu_java_security_provider_GnuDSAPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype _jc_gnu_java_security_provider_GnuDSAPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDSAPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDSAPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDSAPublicKey_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/GnuDSAPublicKey.h <==
// public class gnu.java.security.provider.GnuDSAPublicKey

// class file dependencies
// @dep_class 84d8d4a6e8de7d16 gnu_java_security_provider_GnuDSAPublicKey
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_provider_GnuDSAPublicKey_H_
#define _JC_gnu_java_security_provider_GnuDSAPublicKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;
struct _jc_java_security_interfaces_DSAParams$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs	_jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs	_jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$refs	_jc_gnu_java_security_provider_GnuDSAPublicKey$refs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs	_jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs;
typedef struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object	_jc_gnu_java_security_provider_GnuDSAPublicKey$object;

typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods	_jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtable	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtable;
typedef const struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_GnuDSAPublicKey$method$_init$af886985c1050c26(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getFormat$10e2c7b1e3bfcc3b(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getParams$cf8a9747be586d14(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_provider_GnuDSAPublicKey$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getFormat$10e2c7b1e3bfcc3b;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getParams$cf8a9747be586d14;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$getY$e067a5f1fb934d2a;
extern _jc_method _jc_gnu_java_security_provider_GnuDSAPublicKey$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFormat$10e2c7b1e3bfcc3b)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getParams$cf8a9747be586d14)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vmethods	gnu_java_security_provider_GnuDSAPublicKey;
};

// Vtype
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs {
	_jc_byte_array	*encodedKey;
	struct _jc_java_math_BigInteger$object	*y;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$refs {
    _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_refs	gnu_java_security_provider_GnuDSAPublicKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_provider_GnuDSAPublicKey$sub_nonrefs	gnu_java_security_provider_GnuDSAPublicKey;
};

// Object instance structure
struct _jc_gnu_java_security_provider_GnuDSAPublicKey$object {
	_jc_gnu_java_security_provider_GnuDSAPublicKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$vtype	*vtype;
	_jc_gnu_java_security_provider_GnuDSAPublicKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_GnuDSAPublicKey$vtype _jc_gnu_java_security_provider_GnuDSAPublicKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_GnuDSAPublicKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_GnuDSAPublicKey$class_object;

#endif	/* _JC_gnu_java_security_provider_GnuDSAPublicKey_H_ */
